@@ -47,7 +47,11 @@ class Client:
 
         self.debug(f"> {sys.getsizeof(commands)}")
 
-        res = self.get_rpc().batch_([command.split(" ") for command in commands])
+        try:
+            res = self.get_rpc().batch_([command.split(" ") for command in commands])
+        except JSONRPCException as e:
+            self.debug(f"Error [{e}] (caused by pybitcoinrpc.Client.rpc_execute)")
+            return [{"type": "error", "message": "One of commands failed"} for x in commands]
 
         self.debug(f"< {sys.getsizeof(res)}")
 
